==> down.php?SDK=cocos_V1.20.3.2.zip: cocos_V1.20.3.2/Android/sample/c2s/Classes/DefaultParameters.hpp <==
//
//  DefaultParameters.hpp
//  HIVE_SDK_Cocos_Sample
//
//  Created by sjyong on 2021/10/20.
//

#ifndef DefaultParameters_hpp
#define DefaultParameters_hpp

#include <stdio.h>
#include <string>
#include <set>
#include <vector>
#include <algorithm>
#include <map>

#include "C2SActiveUser.h"
#include "C2SHub2.h"
#include "C2SHivePromotion.h"
#include "C2SInAppV4.h"
#include "C2SPush.h"
#include "C2SMercury.h"

using namespace std;

// MARK: CommonParameters
// 각각 다른 서비스 모듈에서 공통으로 사용하는 파라미터들은 이곳에 저장
class CommonParameters {

private:
    string uid;
    string vid;
    string did;
    string sessionKey;

public:
    void setUid(string value) { uid = value; }
    void setVid(string value) { vid = value; }
    void setDid(string value) { did = value; }
    void setSessionKey(string value) { sessionKey = value; }
    void writeCommonParametersToFile();
    void readCommonParametersFromFile();

    string getUid() { return uid; }
    string getVid() { return vid; }
    string getDid() { return did; }
    string getSessionKey() { return sessionKey; }
};

// MARK : ActiveUserParameters
class ActiveUserParameters {

private:
    /* Default Parameter
     개발자 사이트 설명 기준
     */
    SERVER_STATE serverState = LIVE_SERVER;
    int showNotice = 0;
    string vid = "0";
    string serverId = "kr";
    string gameLanguage = "ko";
    int minTimeoutSeconds = 5;
    int bufSize = 12;        // full size ex : C2S.19.10.10 (12)
    bool isLogged = true;
    string url = "";
    bool isOn = true;
    string funnelsTrack = "700";
    string optionTag = "optionTag";
    string requests = "{\"requests\":[\"android.permission.READ_CONTACTS\"]}";
    int sendLimit = 5;
    int queueLimit = 50;
    int sendCycleSecond = 1;
    string logData = "{\"logId\":1,\"logSubId\":1,\"userId\":\"user001\",\"nickname\":\"게임돌이\"}";
    MODULE_ORIENTATION moduleOrientation = ALL;
    bool isHerculesEnable = true;
    string channel = "C2S";

public:
    void setServerState(SERVER_STATE value) { serverState = value; }
    void setShowNotice(int value) { showNotice = value; }
    void setVid(string value) { vid = value; }
    void setServerId(string value) { serverId = value; }
    void setGameLanguage(string value) { gameLanguage = value; }
    void setMinTimeoutSeconds(int value) { minTimeoutSeconds = value; }
    void setBufSize(int value) { bufSize = value; }
    void setIsLogged(bool value) { isLogged = value; }
    void setUrl(string value) { url = value; }
    void setIsOn(bool value) { isOn = value; }
    void setFunnelsTrack(string value) { funnelsTrack = value; }
    void setOptionTag(string value) { optionTag = value; }
    void setRequests(string value) { requests = value; }
    void setSendLimit(int value) { sendLimit = value; }
    void setQueueLimit(int value) { queueLimit = value; }
    void setSendCycleSecond(int value) { sendCycleSecond = value; }
    void setLogData(string value) { logData = value; }
    void setModuleOrientation(MODULE_ORIENTATION value) { moduleOrientation = value; }
    void setUseHercules(bool value) { isHerculesEnable = value; }
    void setChannel(string value) { channel = value; }

    SERVER_STATE getServerState() { return serverState; }
    int getShowNotice() { return showNotice; }
    string getVid() { return vid; }
    string getServerId() { return serverId; }
    string getGameLanguage() { return gameLanguage; }
    int getMinTimeoutSeconds() { return minTimeoutSeconds; }
    int getBufSize() { return bufSize; }
    bool getIsLogged() { return isLogged; }
    string getUrl() { return url; }
    bool getIsOn() { return isOn; }
    string getFunnelsTrack() { return funnelsTrack; }
    string getOptionTag() { return optionTag; }
    string getRequests() { return requests; }
    int getSendLimit() { return sendLimit; }
    int getQueueLimit() { return queueLimit; }
    int getSendCycleSecond() { return sendCycleSecond; }
    string getLogData() { return logData; }
    MODULE_ORIENTATION getModuleOrientation() { return moduleOrientation; }
    bool getUseHercules() { return isHerculesEnable; }
    string getChannel() { return channel; }
};

// MARK : PeppermintParameters
class PeppermintParameters {

private:
    string requestNameForSocial = "";

    /* hubAsyncRequest의 params 세팅 값을 관리
     * key는 실제 requestName으로 지정
     */
    string requestName;
    map<string, string> params;
    string guestUid = "";
    string candidateUid = "0";
#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    string appId = "com.com2us.hivesdk.normal.freefull.apple.global.ios.universal";
    string gameIndex = "2789";
#else
    string appId = "com.com2us.hivesdk.normal.freefull.google.global.android.common";
    string gameIndex = "2790";
#endif
    bool useTestServer = false;
    HiveSocialServerState serverState = HiveSocialServerLive;
    string key = "";
    string value = "";
    string relativePath = "inquiry";
    string chatbotParam = "{\"evt_code\":1000,\"p1\":\"random\"}";
    string socialService = "facebook";
    string authWithParam = "{\"showGuestLogin\":true}";

public:

    void setRequestNameForSocial(string val) { requestNameForSocial = val; }
    void setRequestName(string val) { requestName = val; }
    void setParams(string _key, string val) { params[_key] = val; }
    void setGuestUid(string val) { guestUid = val; }
    void setAppId(string val) { appId = val; }
    void setGameIndex(string val) { gameIndex = val; }
    void setCandidateUid(string val) { candidateUid = val; }
    void setUseTestSerever(bool val) { useTestServer = val; }
    void setServerState(HiveSocialServerState val) { serverState = val; }
    void setKey(string val) { key = val; }
    void setValue(string  val) { value = val; }
    void setRelativePath(string val) { relativePath = val; }
    void setChatbotParam(string val) { chatbotParam = val; }
    void setSocialService(string val) { socialService = val; }
    void setAuthWithParam(string val) { authWithParam = val; }

    string getRequestNameForSocial() { return requestNameForSocial; }
    string getRequestName() { return requestName; }
    string getParams(string _key) { return params[_key]; }
    string getGuestUid() { return guestUid; }
    string getAppId() { return appId; }
    string getGameIndex() { return gameIndex; }
    string getCandidateUid() { return candidateUid; }
    bool getUseTestServer() { return useTestServer; }
    HiveSocialServerState getServerState() { return serverState; }
    string getKey() { return key; }
    string getValue() { return value; }
    string getRelativePath() { return relativePath; }
    string getChatbotParam() { return chatbotParam; }
    string getSocialService() { return socialService; }
    string getAuthWithParam() { return authWithParam; }
};

// MARK : HivePromotionParameters
class HivePromotionParameters {

private:
    CSPromotionViewType viewType = CSPromotionViewType::CS_PROMOTION_NEWS;
    int isForced = 0;
    string contents = "310000";
    CSPromotionCustomType customType = CSPromotionCustomType::CS_PROMOTION_VIEW;
    string campaignType = "all";
    string bannerType = "great";
    string inviteMessage = "invite message";
    string inviteLink = "";
    string additionalInfo = "";

    // api 파라미터 이외에 관리가 필요한 데이터
    vector<string> inviteLinkList;  // getInvitationData API로 전달 받는 초대링크 리스트 (inviteCommonLink, inviteHivemsgLink, inviteFacebookLink)

public:
    void setViewType(CSPromotionViewType value) { viewType = value; }
    void setIsForced(int value) { isForced = value; }
    void setContents(string value) { contents = value; }
    void setCustomType(CSPromotionCustomType value) { customType = value; }
    void setCampaignType(string value) { campaignType = value; }
    void setBannerType(string value) { bannerType = value; }
    void setInviteMessage(string value) { inviteMessage = value; }
    void setInviteLink(string value) { inviteLink = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }

    CSPromotionViewType getViewType() { return viewType; }
    int getIsForced() { return isForced; }
    string getContents() { return contents; }
    CSPromotionCustomType getCustomType() { return customType; }
    string getCampaignType() { return campaignType; }
    string getBannerType() { return bannerType; }
    string getInviteMessage() { return inviteMessage; }
    string getInviteLink() { return inviteLink; }
    string getAdditionalInfo() { return additionalInfo; }

    vector<string> getInviteLinkList() { return inviteLinkList; }

    void addLinkToInviteLinkList(string value) {
        // 중복 제거
        auto it = find(inviteLinkList.begin(), inviteLinkList.end(), value);
        if (it == inviteLinkList.end()) {
            inviteLinkList.push_back(value);
        }
    }
};

// MARK : OfferwallParameters
class OfferwallParameters {

private:
    int isUsingStaging = 0;
    int isLog = 0;
    string additionalInfo = "";
    string uid = "";

public:
    void setIsUsingStaging(int value) { isUsingStaging = value; }
    void setIsLog(int value) { isLog = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }

    int getIsUsingStaging() { return isUsingStaging; }
    int getIsLog() { return isLog; }
    string getAdditionalInfo() { return additionalInfo; }
    string getUid() { return uid; }
};

// MARK : InAppV4Parameters
class InAppV4Parameters {

private:
    int marketId = 0;
    string marketPid = "";
    string additionalInfo = "";
    string oldMarketPid = "";
#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    string marketProductInfoPidList = "com.com2us.hivesdk.normal.freefull.apple.global.ios.universal.cs01";
#else
    string marketProductInfoPidList = "item01";
#endif

    // api 파라미터 이외에 관리가 필요한 데이터
    vector<string> marketPidList;
    vector<CS_IapV4ReceiptInfo> receiptInfoList;

public:
    void setMarketId(int value) { marketId = value; }
    void setMarketPid(string value) { marketPid = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }
    void setOldMarketPid(string value) { oldMarketPid = value; }
    void setMarketProductInfoPidList(string value) { marketProductInfoPidList = value; }

    int getMarketId() { return marketId; }
    string getMarketPid() { return marketPid; }
    string getAdditionalInfo() { return additionalInfo; }
    string getOldMarketPid() { return oldMarketPid; }
    string getMarketProductInfoPidList() { return marketProductInfoPidList; }

    vector<string> getMarketPidList() { return marketPidList; }

    void addMarketPidToList(string value) {
        // 중복 제거
        auto it = find(marketPidList.begin(), marketPidList.end(), value);
        if (it == marketPidList.end()) {
            marketPidList.push_back(value);
        }
    }

};

// MARK : PushParameters
class PushParameters {

private:
    // Common
    Push_BoolType notice = Push_FALSE;
    Push_BoolType night = Push_FALSE;
    int pushID = 1111;
    string title = "Push title";
    string msg = "Push message";
    string ticker = "";
    string type = "";
    string icon = "";
    string sound = "";
    string active = "";
    long after = 5;
    string broadcastAction;

    // iOS
    void* inData;
    void* userInfo;
    Push_BoolType remote = Push_FALSE;
    Push_BoolType local = Push_FALSE;

    // Android
    Push_BoolType isPush = Push_FALSE;
    Push_BoolType isSound = Push_FALSE;
    Push_BoolType isVib = Push_FALSE;
    string bigmsg = "Push big message" ;
    string jsonPushData = "";
    int boolean = 0;

public:
    // set
    void setNotice(Push_BoolType value) { notice = value; }
    void setNight(Push_BoolType value) { night = value; }
    void setPushID(int value) { pushID = value; }
    void setTitle(string value) { title = value; }
    void setMsg(string value) { msg = value; }
    void setTicker(string  value) { ticker = value; }
    void setType(string value) { type = value; }
    void setIcon(string value) { icon = value; }
    void setSound(string value) { sound = value; }
    void setActive(string value) { active = value; }
    void setAfter(long value) { after = value; }
    void setBroadcastAction(string value) { broadcastAction = value; }

    void setRemote(Push_BoolType value) { remote = value; }
    void setLocal(Push_BoolType value) { local = value; }

    void setIsPush(Push_BoolType value) { isPush = value; }
    void setIsSound(Push_BoolType value) { isSound = value; }
    void setIsVib(Push_BoolType value) { isVib = value; }
    void setBigMsg(string value) { bigmsg = value; }
    void setJsonPushData(string value) { jsonPushData = value; }
    void setBoolean(int value) { boolean = value; }

    // get
    Push_BoolType getNotice() { return notice; }
    Push_BoolType getNight() { return night; }
    int getPushID() { return pushID; }
    string getTitle() { return title; }
    string getMsg() { return msg; }
    string getTicker() { return ticker; }
    string getType() { return type; }
    string getIcon() { return icon; }
    string getSound() { return sound; }
    string getActive() { return active; }
    long getAfter() { return after; }
    string getBroadcastAction() { return broadcastAction; }

    Push_BoolType getRemote() { return remote; }
    Push_BoolType getLocal() { return local; }

    Push_BoolType getIsPush() { return isPush; }
    Push_BoolType getIsSound() { return isSound; }
    Push_BoolType getIsVib() { return isVib; }
    string getBigMsg() { return bigmsg; }
    string getJsonPushData() { return jsonPushData; }
    int getBoolean() { return boolean; }

};

// MARK: MercuryParameters
class MercuryParameters {

private:
    MERCURY_SHOW_TYPE showType = MERCURY_SHOW_EVENT_LEGACY;
    string additionalInfo;
    int viewID;
    int isUsingStaging;
    int isLog;
    int badgeTarget = - 20; // MERCURY_BADGE_FOR_EVENT
    string urlLink = "https://www.withhive.com";
    string shareMessage = "mercury ua link share message.(KS C2S)";
    string campaignType = "all";
    string bannerType = "great";
    int onGameWindow = 0;
    
public:
    void setShowType(MERCURY_SHOW_TYPE value) { showType = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }
    void setViewID(int value) { viewID = value; }
    void setIsUsingStaging(int value) { isUsingStaging = value; }
    void setIsLog(int value) { isLog = value; }
    void setBadgeTarget(int value) { badgeTarget = value; }
    void setUrlLink(string value) { urlLink = value; }
    void setShareMessage(string value) { shareMessage = value; }
    void setCampaignType(string value) { campaignType = value; }
    void setBannerType(string value) { bannerType = value; }
    void setOnGameWindow(int value) { onGameWindow = value; }

    MERCURY_SHOW_TYPE getShowType() { return showType; }
    string getAdditionalInfo() { return additionalInfo; }
    int getViewID() { return viewID; }
    int getIsUsingStaging() { return isUsingStaging; }
    int getIsLog() { return isLog; }
    int getBadgeTarget() { return badgeTarget; }
    string getUrlLink() { return urlLink; }
    string getShareMessage() { return shareMessage; }
    string getCampaignType() { return campaignType; }
    string getBannerType() { return bannerType; }
    int getOnGameWindow() { return onGameWindow; }

};

#endif /* DefaultParameters_hpp */

==> down.php?SDK=cocos_V1.21.1.1.zip: cocos_V1.21.1.1/Android/sample/c2s/Classes/DefaultParameters.hpp <==
//
//  DefaultParameters.hpp
//  HIVE_SDK_Cocos_Sample
//
//  Created by sjyong on 2021/10/20.
//

#ifndef DefaultParameters_hpp
#define DefaultParameters_hpp

#include <stdio.h>
#include <string>
#include <set>
#include <vector>
#include <algorithm>
#include <map>

#include "C2SActiveUser.h"
#include "C2SHub2.h"
#include "C2SHivePromotion.h"
#include "C2SInAppV4.h"
#include "C2SPush.h"
#include "C2SMercury.h"

using namespace std;

// MARK: CommonParameters
// 각각 다른 서비스 모듈에서 공통으로 사용하는 파라미터들은 이곳에 저장
class CommonParameters {

private:
    string uid;
    string vid;
    string did;
    string sessionKey;

public:
    void setUid(string value) { uid = value; }
    void setVid(string value) { vid = value; }
    void setDid(string value) { did = value; }
    void setSessionKey(string value) { sessionKey = value; }
    void writeCommonParametersToFile();
    void readCommonParametersFromFile();

    string getUid() { return uid; }
    string getVid() { return vid; }
    string getDid() { return did; }
    string getSessionKey() { return sessionKey; }
};

// MARK : ActiveUserParameters
class ActiveUserParameters {

private:
    /* Default Parameter
     개발자 사이트 설명 기준
     */
    SERVER_STATE serverState = LIVE_SERVER;
    int showNotice = 0;
    string vid = "0";
    string serverId = "kr";
    string gameLanguage = "ko";
    int minTimeoutSeconds = 5;
    int bufSize = 12;        // full size ex : C2S.19.10.10 (12)
    bool isLogged = true;
    string url = "";
    bool isOn = true;
    string funnelsTrack = "700";
    string optionTag = "optionTag";
    string requests = "{\"requests\":[\"android.permission.READ_CONTACTS\"]}";
    int sendLimit = 5;
    int queueLimit = 50;
    int sendCycleSecond = 1;
    string logData = "{\"logId\":1,\"logSubId\":1,\"userId\":\"user001\",\"nickname\":\"게임돌이\"}";
    MODULE_ORIENTATION moduleOrientation = ALL;
    bool isHerculesEnable = true;
    string channel = "C2S";

public:
    void setServerState(SERVER_STATE value) { serverState = value; }
    void setShowNotice(int value) { showNotice = value; }
    void setVid(string value) { vid = value; }
    void setServerId(string value) { serverId = value; }
    void setGameLanguage(string value) { gameLanguage = value; }
    void setMinTimeoutSeconds(int value) { minTimeoutSeconds = value; }
    void setBufSize(int value) { bufSize = value; }
    void setIsLogged(bool value) { isLogged = value; }
    void setUrl(string value) { url = value; }
    void setIsOn(bool value) { isOn = value; }
    void setFunnelsTrack(string value) { funnelsTrack = value; }
    void setOptionTag(string value) { optionTag = value; }
    void setRequests(string value) { requests = value; }
    void setSendLimit(int value) { sendLimit = value; }
    void setQueueLimit(int value) { queueLimit = value; }
    void setSendCycleSecond(int value) { sendCycleSecond = value; }
    void setLogData(string value) { logData = value; }
    void setModuleOrientation(MODULE_ORIENTATION value) { moduleOrientation = value; }
    void setUseHercules(bool value) { isHerculesEnable = value; }
    void setChannel(string value) { channel = value; }

    SERVER_STATE getServerState() { return serverState; }
    int getShowNotice() { return showNotice; }
    string getVid() { return vid; }
    string getServerId() { return serverId; }
    string getGameLanguage() { return gameLanguage; }
    int getMinTimeoutSeconds() { return minTimeoutSeconds; }
    int getBufSize() { return bufSize; }
    bool getIsLogged() { return isLogged; }
    string getUrl() { return url; }
    bool getIsOn() { return isOn; }
    string getFunnelsTrack() { return funnelsTrack; }
    string getOptionTag() { return optionTag; }
    string getRequests() { return requests; }
    int getSendLimit() { return sendLimit; }
    int getQueueLimit() { return queueLimit; }
    int getSendCycleSecond() { return sendCycleSecond; }
    string getLogData() { return logData; }
    MODULE_ORIENTATION getModuleOrientation() { return moduleOrientation; }
    bool getUseHercules() { return isHerculesEnable; }
    string getChannel() { return channel; }
};

// MARK : PeppermintParameters
class PeppermintParameters {

private:
    string requestNameForSocial = "";

    /* hubAsyncRequest의 params 세팅 값을 관리
     * key는 실제 requestName으로 지정
     */
    string requestName;
    map<string, string> params;
    string guestUid = "";
    string candidateUid = "0";
#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    string appId = "com.com2us.hivesdk.normal.freefull.apple.global.ios.universal";
    string gameIndex = "2789";
#else
    string appId = "com.com2us.hivesdk.normal.freefull.google.global.android.common";
    string gameIndex = "2790";
#endif
    bool useTestServer = false;
    HiveSocialServerState serverState = HiveSocialServerLive;
    string key = "";
    string value = "";
    string relativePath = "inquiry";
    string chatbotParam = "{\"evt_code\":1000,\"p1\":\"random\"}";
    string socialService = "facebook";
    string authWithParam = "{\"showGuestLogin\":true}";

public:

    void setRequestNameForSocial(string val) { requestNameForSocial = val; }
    void setRequestName(string val) { requestName = val; }
    void setParams(string _key, string val) { params[_key] = val; }
    void setGuestUid(string val) { guestUid = val; }
    void setAppId(string val) { appId = val; }
    void setGameIndex(string val) { gameIndex = val; }
    void setCandidateUid(string val) { candidateUid = val; }
    void setUseTestSerever(bool val) { useTestServer = val; }
    void setServerState(HiveSocialServerState val) { serverState = val; }
    void setKey(string val) { key = val; }
    void setValue(string  val) { value = val; }
    void setRelativePath(string val) { relativePath = val; }
    void setChatbotParam(string val) { chatbotParam = val; }
    void setSocialService(string val) { socialService = val; }
    void setAuthWithParam(string val) { authWithParam = val; }

    string getRequestNameForSocial() { return requestNameForSocial; }
    string getRequestName() { return requestName; }
    string getParams(string _key) { return params[_key]; }
    string getGuestUid() { return guestUid; }
    string getAppId() { return appId; }
    string getGameIndex() { return gameIndex; }
    string getCandidateUid() { return candidateUid; }
    bool getUseTestServer() { return useTestServer; }
    HiveSocialServerState getServerState() { return serverState; }
    string getKey() { return key; }
    string getValue() { return value; }
    string getRelativePath() { return relativePath; }
    string getChatbotParam() { return chatbotParam; }
    string getSocialService() { return socialService; }
    string getAuthWithParam() { return authWithParam; }
};

// MARK : HivePromotionParameters
class HivePromotionParameters {

private:
    CSPromotionViewType viewType = CSPromotionViewType::CS_PROMOTION_NEWS;
    int isForced = 0;
    string contents = "310000";
    CSPromotionCustomType customType = CSPromotionCustomType::CS_PROMOTION_VIEW;
    string campaignType = "all";
    string bannerType = "great";
    string inviteMessage = "invite message";
    string inviteLink = "";
    string additionalInfo = "";

    // api 파라미터 이외에 관리가 필요한 데이터
    vector<string> inviteLinkList;  // getInvitationData API로 전달 받는 초대링크 리스트 (inviteCommonLink, inviteHivemsgLink, inviteFacebookLink)

public:
    void setViewType(CSPromotionViewType value) { viewType = value; }
    void setIsForced(int value) { isForced = value; }
    void setContents(string value) { contents = value; }
    void setCustomType(CSPromotionCustomType value) { customType = value; }
    void setCampaignType(string value) { campaignType = value; }
    void setBannerType(string value) { bannerType = value; }
    void setInviteMessage(string value) { inviteMessage = value; }
    void setInviteLink(string value) { inviteLink = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }

    CSPromotionViewType getViewType() { return viewType; }
    int getIsForced() { return isForced; }
    string getContents() { return contents; }
    CSPromotionCustomType getCustomType() { return customType; }
    string getCampaignType() { return campaignType; }
    string getBannerType() { return bannerType; }
    string getInviteMessage() { return inviteMessage; }
    string getInviteLink() { return inviteLink; }
    string getAdditionalInfo() { return additionalInfo; }

    vector<string> getInviteLinkList() { return inviteLinkList; }

    void addLinkToInviteLinkList(string value) {
        // 중복 제거
        auto it = find(inviteLinkList.begin(), inviteLinkList.end(), value);
        if (it == inviteLinkList.end()) {
            inviteLinkList.push_back(value);
        }
    }
};

// MARK : OfferwallParameters
class OfferwallParameters {

private:
    int isUsingStaging = 0;
    int isLog = 0;
    string additionalInfo = "";
    string uid = "";

public:
    void setIsUsingStaging(int value) { isUsingStaging = value; }
    void setIsLog(int value) { isLog = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }

    int getIsUsingStaging() { return isUsingStaging; }
    int getIsLog() { return isLog; }
    string getAdditionalInfo() { return additionalInfo; }
    string getUid() { return uid; }
};

// MARK : InAppV4Parameters
class InAppV4Parameters {

private:
    int marketId = 0;
    string marketPid = "";
    string additionalInfo = "";
    string oldMarketPid = "";
#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    string marketProductInfoPidList = "com.com2us.hivesdk.normal.freefull.apple.global.ios.universal.cs01";
#else
    string marketProductInfoPidList = "item01";
#endif

    // api 파라미터 이외에 관리가 필요한 데이터
    vector<string> marketPidList;
    vector<CS_IapV4ReceiptInfo> receiptInfoList;

public:
    void setMarketId(int value) { marketId = value; }
    void setMarketPid(string value) { marketPid = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }
    void setOldMarketPid(string value) { oldMarketPid = value; }
    void setMarketProductInfoPidList(string value) { marketProductInfoPidList = value; }

    int getMarketId() { return marketId; }
    string getMarketPid() { return marketPid; }
    string getAdditionalInfo() { return additionalInfo; }
    string getOldMarketPid() { return oldMarketPid; }
    string getMarketProductInfoPidList() { return marketProductInfoPidList; }

    vector<string> getMarketPidList() { return marketPidList; }

    void addMarketPidToList(string value) {
        // 중복 제거
        auto it = find(marketPidList.begin(), marketPidList.end(), value);
        if (it == marketPidList.end()) {
            marketPidList.push_back(value);
        }
    }

};

// MARK : PushParameters
class PushParameters {

private:
    // Common
    Push_BoolType notice = Push_FALSE;
    Push_BoolType night = Push_FALSE;
    int pushID = 1111;
    string title = "Push title";
    string msg = "Push message";
    string ticker = "";
    string type = "";
    string icon = "";
    string sound = "";
    string active = "";
    long after = 5;
    string broadcastAction;
    string groupId;

    // iOS
    void* inData;
    void* userInfo;
    Push_BoolType remote = Push_FALSE;
    Push_BoolType local = Push_FALSE;

    // Android
    Push_BoolType isPush = Push_FALSE;
    Push_BoolType isSound = Push_FALSE;
    Push_BoolType isVib = Push_FALSE;
    string bigmsg = "Push big message" ;
    string jsonPushData = "{\"noticeID\":1,\"title\":\"title\",\"msg\":\"message\",\"after\":5,\"groupId\":\"a\"}";;
    int boolean = 0;

public:
    // set
    void setNotice(Push_BoolType value) { notice = value; }
    void setNight(Push_BoolType value) { night = value; }
    void setPushID(int value) { pushID = value; }
    void setTitle(string value) { title = value; }
    void setMsg(string value) { msg = value; }
    void setTicker(string  value) { ticker = value; }
    void setType(string value) { type = value; }
    void setIcon(string value) { icon = value; }
    void setSound(string value) { sound = value; }
    void setActive(string value) { active = value; }
    void setAfter(long value) { after = value; }
    void setBroadcastAction(string value) { broadcastAction = value; }
    void setGroupId(string value) { groupId = value; }

    void setRemote(Push_BoolType value) { remote = value; }
    void setLocal(Push_BoolType value) { local = value; }

    void setIsPush(Push_BoolType value) { isPush = value; }
    void setIsSound(Push_BoolType value) { isSound = value; }
    void setIsVib(Push_BoolType value) { isVib = value; }
    void setBigMsg(string value) { bigmsg = value; }
    void setJsonPushData(string value) { jsonPushData = value; }
    void setBoolean(int value) { boolean = value; }

    // get
    Push_BoolType getNotice() { return notice; }
    Push_BoolType getNight() { return night; }
    int getPushID() { return pushID; }
    string getTitle() { return title; }
    string getMsg() { return msg; }
    string getTicker() { return ticker; }
    string getType() { return type; }
    string getIcon() { return icon; }
    string getSound() { return sound; }
    string getActive() { return active; }
    long getAfter() { return after; }
    string getBroadcastAction() { return broadcastAction; }
    string getGroupId() { return groupId; }

    Push_BoolType getRemote() { return remote; }
    Push_BoolType getLocal() { return local; }

    Push_BoolType getIsPush() { return isPush; }
    Push_BoolType getIsSound() { return isSound; }
    Push_BoolType getIsVib() { return isVib; }
    string getBigMsg() { return bigmsg; }
    string getJsonPushData() { return jsonPushData; }
    int getBoolean() { return boolean; }

};

// MARK: MercuryParameters
class MercuryParameters {

private:
    MERCURY_SHOW_TYPE showType = MERCURY_SHOW_EVENT_LEGACY;
    string additionalInfo;
    int viewID;
    int isUsingStaging;
    int isLog;
    int badgeTarget = - 20; // MERCURY_BADGE_FOR_EVENT
    string urlLink = "https://www.withhive.com";
    string shareMessage = "mercury ua link share message.(KS C2S)";
    string campaignType = "all";
    string bannerType = "great";
    int onGameWindow = 0;
    
public:
    void setShowType(MERCURY_SHOW_TYPE value) { showType = value; }
    void setAdditionalInfo(string value) { additionalInfo = value; }
    void setViewID(int value) { viewID = value; }
    void setIsUsingStaging(int value) { isUsingStaging = value; }
    void setIsLog(int value) { isLog = value; }
    void setBadgeTarget(int value) { badgeTarget = value; }
    void setUrlLink(string value) { urlLink = value; }
    void setShareMessage(string value) { shareMessage = value; }
    void setCampaignType(string value) { campaignType = value; }
    void setBannerType(string value) { bannerType = value; }
    void setOnGameWindow(int value) { onGameWindow = value; }

    MERCURY_SHOW_TYPE getShowType() { return showType; }
    string getAdditionalInfo() { return additionalInfo; }
    int getViewID() { return viewID; }
    int getIsUsingStaging() { return isUsingStaging; }
    int getIsLog() { return isLog; }
    int getBadgeTarget() { return badgeTarget; }
    string getUrlLink() { return urlLink; }
    string getShareMessage() { return shareMessage; }
    string getCampaignType() { return campaignType; }
    string getBannerType() { return bannerType; }
    int getOnGameWindow() { return onGameWindow; }

};

#endif /* DefaultParameters_hpp */
